@@ -17,6 +17,7 @@ class quantum_lab():
         # self.filePath = filePath
         self.volumeName = volumeName
         self.resourceName = resourceName
+        self.url = "http://job-management.qcc.svc.cluster.local"
 
     def error_handler(self, response):
         if response.status_code == 204:
@@ -34,8 +35,7 @@ class quantum_lab():
             filePath: str, 
             timeout = 120
         ):
-        url = "http://job-management.qcc.svc.cluster.local"
-        url_path = f"{url}/qcc/notebook/job"
+        url_path = f"{self.url}/qcc/notebook/job"
 
         headers = {
             "Content-Type": "application/json",
@@ -65,7 +65,7 @@ class quantum_lab():
         time_num = 0
         while True:
             time.sleep(1)
-            response = requests.get(f"http://sdt-api.qcc.svc.cluster.local/qcc/notebook/job/{jobID}", headers=headers) 
+            response = requests.get(f"{self.url}/qcc/notebook/job/{jobID}", headers=headers) 
             data = response.json()
             p_status = data["jobStatus"]
             print(f"Time: {time_num} / Job Status: {p_status}        ", end='\r')
@@ -85,8 +85,7 @@ class quantum_lab():
             shot: int, 
             filePath: str, 
         ):
-        url = "http://sdt-api.qcc.svc.cluster.local"
-        url_path = f"{url}/qcc/notebook/job"
+        url_path = f"{self.url}/qcc/notebook/job"
 
         headers = {
             "Content-Type": "application/json",
@@ -115,8 +114,7 @@ class quantum_lab():
         return data["jobId"]
 
     def getList(self, limit = 0):
-        url = "http://sdt-api.qcc.svc.cluster.local"
-        url_path = f"{url}/qcc/notebook/jobs"
+        url_path = f"{self.url}/qcc/notebook/jobs"
 
         headers = {
             "Content-Type": "application/json",
@@ -166,8 +164,7 @@ class quantum_lab():
         return data["jobs"]
 
     def getJob(self, id: int):
-        url = "http://sdt-api.qcc.svc.cluster.local"
-        url_path = f"{url}/qcc/notebook/job/{id}"
+        url_path = f"{self.url}/qcc/notebook/job/{id}"
 
         headers = {
             "Content-Type": "application/json",
@@ -211,8 +208,7 @@ class quantum_lab():
         return data
 
     def delete(self, id: str):
-        url = "http://sdt-api.qcc.svc.cluster.local"
-        url_path = f"{url}/qcc/notebook/job/{id}"
+        url_path = f"{self.url}/qcc/notebook/job/{id}"
 
         headers = {
             "Content-Type": "application/json",
